# python-package-archetype

Python boiler plate project for creating PyPI packages
https://www.youtube.com/watch?v=nelRslDOK_Y 
https://betterscientificsoftware.github.io/python-for-hpc/tutorials/python-pypi-packaging/ 

# CLI to update
python setup.py sdist upload -r pypi
## Installation

git clone git@github.com:DEV3L/python-package-archetype.git
## License

MIT
